Type: Package
Package: teal.modules.general
Title: General Modules for 'teal' Applications
Version: 0.7.0
Date: 2026-06-25
Authors@R: c(
     person("Dony", "Unardi", , "unardid@gene.com", role = c("aut", "cre")),
    person("Dawid", "Kaledkowski", , "dawid.kaledkowski@roche.com", role = c("aut")),
    person("Pawel", "Rucki", , "pawel.rucki@roche.com", role = "aut"),
    person("Mahmoud", "Hallal", , "mahmoud.hallal@roche.com", role = "aut"),
    person("Ondrej", "Slama", , "ondrej.slama@roche.com", role = "ctb"),
    person("Maciej", "Nasinski", role = "aut"),
    person("Konrad", "Pagacz", role = "aut"),
    person("Nikolas", "Burkoff", role = "aut"),
    person("F. Hoffmann-La Roche AG", role = c("cph", "fnd"))
  )
Description: Prebuilt 'shiny' modules containing tools for viewing data,
    visualizing data, understanding missing and outlier values within your
    data and performing simple data analysis.  This extends 'teal'
    framework that supports reproducible research and analysis.
License: Apache License 2.0
URL: https://insightsengineering.github.io/teal.modules.general/,
        https://github.com/insightsengineering/teal.modules.general/
BugReports: https://github.com/insightsengineering/teal.modules.general/issues
Depends: ggplot2 (>= 3.5.0), R (>= 4.1), shiny (>= 1.8.1), teal (>=
        1.2.0), teal.transform (>= 0.7.0)
Imports: bslib (>= 0.8.0), checkmate (>= 2.1.0), colourpicker (>=
        1.3.0), dplyr (>= 1.1.0), DT (>= 0.13), forcats (>= 1.0.0),
        generics (>= 0.1.3), ggExtra (>= 0.10.1), ggpmisc (>= 0.5.6),
        ggpp (>= 0.5.8-1), ggrepel (>= 0.9.6), goftest (>= 1.2-3),
        grid, gridExtra (>= 2.3), htmlwidgets (>= 1.6.4), jsonlite (>=
        1.8.9), lifecycle (>= 0.2.0), MASS (>= 7.3-60), patchwork (>=
        1.2.0), rmarkdown (>= 2.23), rtables (>= 0.6.11), scales (>=
        1.3.0), shinyjs (>= 2.1.0), shinyTree (>= 0.2.8), shinyvalidate
        (>= 0.1.3), shinyWidgets (>= 0.5.1), sparkline (>= 2.0), stats,
        stringr (>= 1.4.1), teal.code (>= 0.7.0), teal.data (>= 0.8.0),
        teal.logger (>= 0.4.0), teal.reporter (>= 0.6.2), teal.widgets
        (>= 0.5.2), tern (>= 0.9.7), tibble (>= 2.0.0), tidyr (>=
        0.8.3), tools, utils
Suggests: knitr (>= 1.42), logger (>= 0.4.0), nestcolor (>= 0.1.0),
        pkgload, rlang (>= 1.0.0), roxy.shinylive, rvest, shinytest2,
        testthat (>= 3.1.9), withr (>= 2.0.0)
VignetteBuilder: knitr, rmarkdown
Config/Needs/verdepcheck: haleyjeppson/ggmosaic, tidyverse/ggplot2,
        rstudio/shiny, insightsengineering/teal,
        insightsengineering/teal.transform, mllg/checkmate,
        tidyverse/dplyr, rstudio/DT, tidyverse/forcats,
        r-lib/lifecycle, r-lib/scales, daattali/shinyjs,
        shinyTree/shinyTree, rstudio/shinyvalidate,
        dreamRs/shinyWidgets, tidyverse/stringr,
        insightsengineering/teal.code, insightsengineering/teal.data,
        insightsengineering/teal.logger,
        insightsengineering/teal.reporter,
        insightsengineering/teal.widgets, insightsengineering/tern,
        tidyverse/tibble, tidyverse/tidyr, daattali/colourpicker,
        daattali/ggExtra, aphalo/ggpmisc, aphalo/ggpp, slowkow/ggrepel,
        baddstats/goftest, ramnathv/htmlwidgets, jeroen/jsonlite,
        yihui/knitr, daroczig/logger, thomasp85/patchwork,
        insightsengineering/nestcolor, r-lib/pkgload, r-lib/rlang,
        rstudio/rmarkdown, insightsengineering/roxy.shinylive,
        insightsengineering/rtables, tidyverse/rvest,
        htmlwidgets/sparkline, rstudio/shinytest2, r-lib/testthat,
        r-lib/withr
Config/Needs/website: insightsengineering/nesttemplate
Config/roxygen2/version: 8.0.0
Encoding: UTF-8
Language: en-US
NeedsCompilation: no
Packaged: 2026-06-30 22:44:11 UTC; averissimo
Author: Dony Unardi [aut, cre],
  Dawid Kaledkowski [aut],
  Pawel Rucki [aut],
  Mahmoud Hallal [aut],
  Ondrej Slama [ctb],
  Maciej Nasinski [aut],
  Konrad Pagacz [aut],
  Nikolas Burkoff [aut],
  F. Hoffmann-La Roche AG [cph, fnd]
Maintainer: Dony Unardi <unardid@gene.com>
Repository: CRAN
Date/Publication: 2026-07-01 07:00:02 UTC
Built: R 4.4.3; ; 2026-07-01 08:36:45 UTC; unix
