# Generated by roxygen2: do not edit by hand

S3method(create_sparklines,Date)
S3method(create_sparklines,POSIXct)
S3method(create_sparklines,POSIXlt)
S3method(create_sparklines,character)
S3method(create_sparklines,default)
S3method(create_sparklines,factor)
S3method(create_sparklines,logical)
S3method(create_sparklines,numeric)
S3method(teal.reporter::to_rmd,markdown_internal)
S3method(tools::toHTML,markdown_internal)
export(add_facet_labels)
export(geom_mosaic)
export(tm_a_pca)
export(tm_a_regression)
export(tm_data_table)
export(tm_file_viewer)
export(tm_front_page)
export(tm_g_association)
export(tm_g_bivariate)
export(tm_g_distribution)
export(tm_g_response)
export(tm_g_scatterplot)
export(tm_g_scatterplotmatrix)
export(tm_missing_data)
export(tm_outliers)
export(tm_rmarkdown)
export(tm_t_crosstable)
export(tm_variable_browser)
import(ggplot2)
import(shiny)
import(teal)
import(teal.transform)
importFrom(dplyr,"%>%")
importFrom(dplyr,.data)
importFrom(lifecycle,deprecated)
